# TODO

-   Add an xlsx dialect that only creates tabs for sets with cards present in the collection?
-   Group sets by parent set is xlsx output?
    -   Block? probably not
-   diffs to stdout
-   Update card_count for sets when processing bundle filters
-   Switch to hatchling as our build system?
